@@ -17,14 +17,8 @@ from typing import Any, Callable, Deque, Optional
 from weakref import WeakSet
 
 import zmq
-
-if zmq.pyzmq_version_info() >= (17, 0):
-    from tornado.ioloop import IOLoop
-else:
-    # deprecated since pyzmq 17
-    from zmq.eventloop.ioloop import IOLoop
-
 from jupyter_client.session import extract_header
+from tornado.ioloop import IOLoop
 from zmq.eventloop.zmqstream import ZMQStream
 
 # -----------------------------------------------------------------------------
@@ -78,7 +72,6 @@ class IOPubThread:
 
     def _thread_main(self):
         """The inner loop that's actually run in a thread"""
-        self.io_loop.make_current()
         self.io_loop.start()
         self.io_loop.close(all_fds=True)
 
